@@ -38,33 +38,33 @@ nanotest(daemons(0L) == 0L)
 nanotest(daemons()[["daemons"]] == 0L)
 Sys.sleep(0.2)
 if (Sys.info()[["sysname"]] != "Windows" || length(R.version$crt)) {
-  nanotest(daemons(url = value <- sprintf(mirai:::.urlfmt, runif(1, 1000000, 9999999)), dispatcher = FALSE) == value)
-  nanotest(daemons(0L) == 0L)
-  Sys.sleep(0.2)
-  nanotest(daemons(url = value <- "ws://:0", dispatcher = FALSE) != value)
-  nanotest(daemons(0L) == 0L)
-  Sys.sleep(0.2)
-  nanotest(daemons(1L, dispatcher = FALSE, walltime = 500L, timerstart = 1L, .compute = "new") == 1L)
-  mn <- mirai("test", .compute = "new")
-  mp <- mirai("test2", .compute = "new")
-  nanotest(call_mirai(mn)$data == "test")
-  nanotest(call_mirai(mp)$data == "test2")
-  nanotest(daemons(.compute = "new")[["connections"]] == 1L)
-  Sys.sleep(0.8)
-  nanotest(daemons(.compute = "new")[["connections"]] == 0L)
-  nanotest(daemons(0L, .compute = "new") == 0L)
+nanotest(daemons(url = value <- sprintf(mirai:::.urlfmt, runif(1, 1000000, 9999999)), dispatcher = FALSE) == value)
+nanotest(daemons(0L) == 0L)
+Sys.sleep(0.2)
+nanotest(daemons(url = value <- "ws://:0", dispatcher = FALSE) != value)
+nanotest(daemons(0L) == 0L)
+Sys.sleep(0.2)
+nanotest(daemons(1L, dispatcher = FALSE, walltime = 500L, timerstart = 1L, .compute = "new") == 1L)
+mn <- mirai("test", .compute = "new")
+mp <- mirai("test2", .compute = "new")
+nanotest(call_mirai(mn)$data == "test")
+nanotest(call_mirai(mp)$data == "test2")
+nanotest(daemons(.compute = "new")[["connections"]] == 1L)
+Sys.sleep(0.8)
+nanotest(daemons(.compute = "new")[["connections"]] == 0L)
+nanotest(daemons(0L, .compute = "new") == 0L)
 }
-if (Sys.getenv("NOT_CRAN") == "set") {
-  nanotest(daemons(1, dispatcher = TRUE, maxtasks = 10L) == 1L)
-  mq <- mirai("server")
-  nanotest(call_mirai(mq)$data == "server")
-  nanotest(is.matrix(daemons()[["daemons"]]))
-  nanotest(daemons(0) == 0L)
-  Sys.sleep(0.2)
-  nanotest(daemons(n = 2, "ws://:0") == 2L)
-  nanotest(is.matrix(nodes <- daemons()[["daemons"]]) || is_error_value(nodes))
-  nanotest(daemons(0) == 0L)
-  Sys.sleep(0.2)
+if (Sys.getenv("NOT_CRAN") == "true") {
+nanotest(daemons(1, dispatcher = TRUE, maxtasks = 10L) == 1L)
+mq <- mirai("server")
+nanotest(call_mirai(mq)$data == "server")
+nanotest(is.matrix(daemons()[["daemons"]]))
+nanotest(daemons(0) == 0L)
+Sys.sleep(0.2)
+nanotest(daemons(n = 2, "ws://:0") == 2L)
+nanotest(is.matrix(nodes <- daemons()[["daemons"]]) || is_error_value(nodes))
+nanotest(daemons(0) == 0L)
+Sys.sleep(0.2)
 }
 nanotesterr(daemons(url = "URL"), "argument")
 nanotesterr(daemons(-1), "zero or greater")
@@ -76,4 +76,5 @@ me$data
 m
 b
 r
+Sys.sleep(0.2)
 
